@@ -234,7 +234,7 @@ def color_palette(palette=None, n_colors=None, desat=None, as_cmap=False):
                 # Perhaps a named matplotlib colormap?
                 palette = mpl_palette(palette, n_colors, as_cmap=as_cmap)
             except (ValueError, KeyError):  # Error class changed in mpl36
-                raise ValueError(f"{palette} is not a valid palette name")
+                raise ValueError(f"{palette!r} is not a valid palette name")
 
     if desat is not None:
         palette = [desaturate(c, desat) for c in palette]
@@ -388,7 +388,7 @@ def mpl_palette(name, n_colors=6, as_cmap=False):
 
     Examples
     --------
-    .. include: ../docstrings/mpl_palette.rst
+    .. include:: ../docstrings/mpl_palette.rst
 
     """
     if name.endswith("_d"):
@@ -474,9 +474,9 @@ def dark_palette(color, n_colors=6, reverse=False, as_cmap=False, input="rgb"):
 
     """
     rgb = _color_to_rgb(color, input)
-    h, s, l = husl.rgb_to_husl(*rgb)
-    gray_s, gray_l = .15 * s, 15
-    gray = _color_to_rgb((h, gray_s, gray_l), input="husl")
+    hue, sat, _ = husl.rgb_to_husl(*rgb)
+    gray_s, gray_l = .15 * sat, 15
+    gray = _color_to_rgb((hue, gray_s, gray_l), input="husl")
     colors = [rgb, gray] if reverse else [gray, rgb]
     return blend_palette(colors, n_colors, as_cmap)
 
@@ -522,9 +522,9 @@ def light_palette(color, n_colors=6, reverse=False, as_cmap=False, input="rgb"):
 
     """
     rgb = _color_to_rgb(color, input)
-    h, s, l = husl.rgb_to_husl(*rgb)
-    gray_s, gray_l = .15 * s, 95
-    gray = _color_to_rgb((h, gray_s, gray_l), input="husl")
+    hue, sat, _ = husl.rgb_to_husl(*rgb)
+    gray_s, gray_l = .15 * sat, 95
+    gray = _color_to_rgb((hue, gray_s, gray_l), input="husl")
     colors = [rgb, gray] if reverse else [gray, rgb]
     return blend_palette(colors, n_colors, as_cmap)
 
@@ -839,4 +839,3 @@ def set_color_codes(palette="deep"):
     for code, color in zip("bgrmyck", colors):
         rgb = mpl.colors.colorConverter.to_rgb(color)
         mpl.colors.colorConverter.colors[code] = rgb
-        mpl.colors.colorConverter.cache[code] = rgb
